@@ -10,7 +10,7 @@ use Bat::Interpreter::Delegate::FileStore::LocalFileSystem;
 use Bat::Interpreter::Delegate::Executor::PartialDryRunner;
 use namespace::autoclean;
 
-our $VERSION = '0.006';    # VERSION
+our $VERSION = '0.007';    # VERSION
 
 # ABSTRACT: Pure perl interpreter for a small subset of bat/cmd files
 
@@ -188,15 +188,22 @@ sub _handle_special_command {
         if ( $token =~ /^:/ ) {
             $self->_goto_label( $token, $context );
         } else {
+            ( my $first_word ) = $token =~ /\A([^:\s]+)/;
+            if ( $first_word =~ /(\.[^.]+)$/ ) {
+                ( my $extension ) = $first_word =~ /(\.[^.]+)$/;
+                if ( $extension eq '.exe' ) {
+                    $self->_execute_command( $token, $context );
+                } elsif ( $extension eq '.bat' || $extension eq '.cmd' ) {
 
-            # Must be a file
-            #print "Calling file: $token\n";
-            my $stdout = $self->run( $token, $context->{ENV} );
-            if ( !defined $context->{STDOUT} ) {
-                $context->{STDOUT} = [];
-            }
-            if ( defined $stdout ) {
-                push @{ $context->{STDOUT} }, @$stdout;
+                    #print "Calling file: $token\n";
+                    my $stdout = $self->run( $token, $context->{ENV} );
+                    if ( !defined $context->{STDOUT} ) {
+                        $context->{STDOUT} = [];
+                    }
+                    if ( defined $stdout ) {
+                        push @{ $context->{STDOUT} }, @$stdout;
+                    }
+                }
             }
         }
     }
@@ -387,7 +394,7 @@ Bat::Interpreter - Pure perl interpreter for a small subset of bat/cmd files
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
